/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_CALENDAR_H
#define __KIBA_CALENDAR_H

#include <gtk/gtk.h>

#include <kiba-info-win.h>
#include <kiba-prefs.h>

G_BEGIN_DECLS

typedef struct _KibaCalendar       KibaCalendar;
typedef struct _KibaCalendarClass  KibaCalendarClass;

#define KIBA_TYPE_CALENDAR           (kiba_calendar_get_type ())
#define KIBA_CALENDAR(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_CALENDAR, KibaCalendar))
#define KIBA_CALENDAR_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_TYPE_CALENDAR,  KibaCalendarClass))
#define KIBA_IS_CALENDAR(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_CALENDAR))
#define KIBA_IS_CALENDAR_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_CALENDAR))
#define KIBA_CALENDAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_CALENDAR, KibaCalendarClass))

struct _KibaCalendar {
	KibaInfoWin parent;
	
KibaPrefsFile *file;
	GList *reminders;
};

struct _KibaCalendarClass {
	KibaInfoWinClass parent_class;
};

typedef struct {
	KibaCalendar *calendar;
	
	gboolean active;
	gchar *desktop_uri;
	gchar *description;
	gchar *summary;
	unsigned int expire_time;
	
	struct {
		unsigned int minute;
		unsigned int hour;
		unsigned int day;
		unsigned int month;
		unsigned int year;
	}time;
	
	struct {
		GtkWidget *win;
		GtkWidget *expire_hour_spin;
		GtkWidget *expire_minute_spin;
		GtkWidget *minute_spin;
		GtkWidget *hour_spin;
		GtkWidget *textview;
		GtkWidget *summary;
	}dialog;
}KibaCalendarReminder;

KibaCalendar* kiba_calendar_new (void);

void kiba_calendar_show_reminder_for_date (KibaCalendar *calendar,
                                           KibaCalendarReminder *reminder,
                                           unsigned int year,
                                           unsigned int month,
                                           unsigned int day);

#endif
