/*
 *  Copyright (C) 2008  Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#include "config.h"
#include "kiba-mime-application-chooser.h"

#include "kiba-mime-extensions.h"

typedef struct {
	GtkWidget *mainbox;
	char *mime_type;
	GList *mime_apps;
}KibaMimeApplicationChooser;

/*** private methods ***/

static void __app_item_toggled (GtkToggleButton *togglebutton,
                                gpointer user_data) {
	KibaMimeApplication *app = user_data;
	KibaMimeApplicationChooser *chooser;
	
	if (!gtk_toggle_button_get_active (togglebutton))
		return;
	
	chooser = g_object_get_data(G_OBJECT(togglebutton), "mime-chooser");
	
	if (!kiba_mime_set_default_application (chooser->mime_type, app->id)) {
		DEBUG_ERROR("Failed to set default mime application for '%s' to '%s'\n", chooser->mime_type, app->id);
	}
}

static void __cleanup_app_item (GtkWidget *appWidget,
                                gpointer data) {
	g_object_set_data(G_OBJECT(appWidget), "mime-chooser", NULL);
}

static GtkWidget* __add_application (KibaMimeApplicationChooser *chooser,
                                     GtkWidget *group_member,
                                     KibaMimeApplication *app) {
	GtkWidget *appWidget;
	GtkWidget *iconBox;
	GtkWidget *icon;
	GdkPixbuf *pixbuf;
	GtkWidget *label;
	
	/* Create a radio button with a GtkEntry widget */
	if (!group_member)
		appWidget = gtk_radio_button_new (NULL);
	else
		appWidget = gtk_radio_button_new_from_widget (GTK_RADIO_BUTTON(group_member));
	
	iconBox = gtk_hbox_new(FALSE, 3);
		pixbuf = kiba_mime_get_icon(app);
		icon = gtk_image_new_from_pixbuf (pixbuf);
		if (pixbuf != NULL)
			g_object_unref(G_OBJECT(pixbuf));
		else
			gtk_widget_set_usize(icon, 24, 24);
		gtk_box_pack_start (GTK_BOX (iconBox), icon, FALSE, FALSE, 2);
		
		label = gtk_label_new(app->name);
		gtk_box_pack_start (GTK_BOX (iconBox), label, TRUE, TRUE, 2);
	gtk_container_add (GTK_CONTAINER (appWidget), iconBox);
	
	gtk_box_pack_start (GTK_BOX (chooser->mainbox), appWidget, FALSE, FALSE, 2);
	
	g_object_set_data(G_OBJECT(appWidget), "mime-chooser", chooser);
	
	g_signal_connect(G_OBJECT(appWidget), "toggled",
		G_CALLBACK(__app_item_toggled), app);
	g_signal_connect(G_OBJECT(appWidget), "destroy",
		G_CALLBACK(__cleanup_app_item), NULL);
	
	return appWidget;
}

static void __cleanup (GtkWidget *widget,
                       gpointer data) {
	KibaMimeApplicationChooser *chooser = data;
	GList *l;
	
	g_free(chooser->mime_type);
	
	for (l = chooser->mime_apps; l != NULL; l = chooser->mime_apps) {
		KibaMimeApplication *app = l->data;
		GtkWidget *toggleButton;
		
		chooser->mime_apps = g_list_remove(chooser->mime_apps, l->data);
		kiba_mime_application_free(app);
	}
	g_list_free(chooser->mime_apps);
	
	g_free(chooser);
}

/*** public methods ***/

/*
TODO:
	* add mime application button
	* remove mime application button
*/

GtkWidget* kiba_mime_application_chooser_new (const char *uri,
                                              const char *mime_type) {
	GList *l;
	GtkWidget *group_member = NULL;
	KibaMimeApplicationChooser *chooser;
	
	chooser = g_new0(KibaMimeApplicationChooser, 1);
	chooser->mime_type = g_strdup(mime_type);
	chooser->mainbox = gtk_vbox_new (FALSE, 2);
	chooser->mime_apps = kiba_mime_get_available_mime_types (mime_type);
	
	for (l = chooser->mime_apps; l != NULL; l = l->next) {
		KibaMimeApplication *app = l->data;
		GtkWidget *toggleButton;
		
		toggleButton = __add_application(chooser, group_member, app);
		gtk_widget_show(toggleButton);
		group_member = toggleButton;
	}
	
	g_signal_connect(G_OBJECT(chooser->mainbox), "destroy",
		G_CALLBACK(__cleanup), chooser);
	
	return chooser->mainbox;
}
