/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_STACK_H
#define __KIBA_STACK_H

#include <glib.h>

#include <kiba-plugin.h>
#include <kiba-plugin-loader.h>
#include <kiba-prefs.h>
#include <kiba-icon-view-win.h>

G_BEGIN_DECLS

typedef struct _KibaStack KibaStack;
typedef struct _KibaStackPlugin KibaStackPlugin;

#include "stack-icon.h"

#define STACK_PLUGIN_NAME "stack"
#define STACK_DIR "/.kiba-dock/" STACK_PLUGIN_NAME

struct _KibaStackPlugin {
	KibaPlugin *plugin;
	KibaPrefsFile *file;
	
	GList *stacks; /* list with all KibaStack's */
	
	/** Properties **/
	gint view_icon_size;
	gint view_rows;
	gint view_columns;
	gboolean open_dirs;
	
	KibaPluginService *loadThumb;
	KibaPluginService *factoryGet;
};

struct _KibaStack {
	KibaStackPlugin *stack_plugin; /* the KibaStackPlugin instance, the pointer is the same for each stack */
	
	char *uri;  /* stack uri (usually ~/.kiba-dock/stack/*.stack) */
	GtkWidget *widget;  /* the object on the dock representing this stack */
	
	GList *icons;   /* list with all KibaStackIcon's */
};

KibaStack* kiba_stack_new (KibaStackPlugin *plugin,
                           const char *uri);

void kiba_stack_destroy (KibaStack *stack);

void kiba_stack_activate_icon (KibaStackIcon *icon);

GtkWidget* kiba_stack_create_context_menu_for_icon (KibaStackIcon *icon);

void kiba_stack_select_icon (KibaStack *stack,
			     KibaStackIcon *icon);

void kiba_stack_remove (KibaStack *stack,
                        KibaStackIcon *icon);

gboolean kiba_stack_drag_receive_cb (KibaStack        *stack,
					    GdkDragContext   *drag_context,
					    GtkSelectionData *selection_data);

// void kiba_stack_toggle_icon_view (KibaStack *stack);

G_END_DECLS

#endif
